@@ -684,10 +684,10 @@ class SymbolicOperator(metaclass=abc.ABCMeta):
         Compute the induced p-norm of the operator.
 
         If we represent an operator as
-        :math: `\sum_{j} w_j H_j`
-        where :math: `w_j` are scalar coefficients then this norm is
-        :math: `\left(\sum_{j} \| w_j \|^p \right)^{\frac{1}{p}}
-        where :math: `p` is the order of the induced norm
+        $\sum_{j} w_j H_j$
+        where $w_j$ are scalar coefficients then this norm is
+        $\left(\sum_{j} \| w_j \|^p \right)^{\frac{1}{p}}$
+        where $p$ is the order of the induced norm
 
         Args:
             order(int): the order of the induced norm.
