@@ -27,26 +27,26 @@ class QuadraticHamiltonian(PolynomialTensor):
     r"""Class for storing Hamiltonians that are quadratic in the fermionic
     ladder operators. The operators stored in this class take the form
 
-    .. math::
-
+    $$
         \sum_{p, q} (M_{pq} - \mu \delta_{pq}) a^\dagger_p a_q
         + \frac12 \sum_{p, q}
             (\Delta_{pq} a^\dagger_p a^\dagger_q + \text{h.c.})
         + \text{constant}
+    $$
 
     where
 
-        - :math:`M` is a Hermitian `n_qubits` x `n_qubits` matrix.
-        - :math:`\Delta` is an antisymmetric `n_qubits` x `n_qubits` matrix.
-        - :math:`\mu` is a real number representing the chemical potential.
-        - :math:`\delta_{pq}` is the Kronecker delta symbol.
+        - $M$ is a Hermitian `n_qubits` x `n_qubits` matrix.
+        - $\Delta$ is an antisymmetric `n_qubits` x `n_qubits` matrix.
+        - $\mu$ is a real number representing the chemical potential.
+        - $\delta_{pq}$ is the Kronecker delta symbol.
 
-    We separate the chemical potential :math:`\mu` from :math:`M` so that
+    We separate the chemical potential $\mu$ from $M$ so that
     we can use it to adjust the expectation value of the total number of
     particles.
 
     Attributes:
-        chemical_potential(float): The chemical potential :math:`\mu`.
+        chemical_potential(float): The chemical potential $\mu$.
     """
     def __init__(self,
                  hermitian_part,
@@ -57,18 +57,18 @@ class QuadraticHamiltonian(PolynomialTensor):
         Initialize the QuadraticHamiltonian class.
 
         Args:
-            hermitian_part(ndarray): The matrix :math:`M`, which represents the
+            hermitian_part(ndarray): The matrix $M$, which represents the
                 coefficients of the particle-number-conserving terms.
                 This is an `n_qubits` x `n_qubits` numpy array of complex
                 numbers.
-            antisymmetric_part(ndarray): The matrix :math:`\Delta`,
+            antisymmetric_part(ndarray): The matrix $\Delta$,
                 which represents the coefficients of the
                 non-particle-number-conserving terms.
                 This is an `n_qubits` x `n_qubits` numpy array of complex
                 numbers.
             constant(float, optional): A constant term in the operator.
             chemical_potential(float, optional): The chemical potential
-                :math:`\mu`.
+                $\mu$.
         """
         n_qubits = hermitian_part.shape[0]
 
@@ -145,21 +145,21 @@ class QuadraticHamiltonian(PolynomialTensor):
 
         Any quadratic Hamiltonian can be written in the form
 
-        .. math::
-
+        $$
             \frac{i}{2} \sum_{j, k} A_{jk} f_j f_k + \text{constant}
+        $$
 
-        where the :math:`f_i` are normalized Majorana fermion operators:
-
-        .. math::
+        where the $f_i$ are normalized Majorana fermion operators:
 
+        $$
             f_j = \frac{1}{\sqrt{2}} (a^\dagger_j + a_j)
 
             f_{j + N} = \frac{i}{\sqrt{2}} (a^\dagger_j - a_j)
+        $$
 
-        and :math:`A` is a (2 * `n_qubits`) x (2 * `n_qubits`) real
+        and $A$ is a (2 * `n_qubits`) x (2 * `n_qubits`) real
         antisymmetric matrix. This function returns the matrix
-        :math:`A` and the constant.
+        $A$ and the constant.
         """
         hermitian_part = self.combined_hermitian_part
         antisymmetric_part = self.antisymmetric_part
@@ -194,18 +194,17 @@ class QuadraticHamiltonian(PolynomialTensor):
 
         Any quadratic Hamiltonian can be rewritten in the form
 
-        .. math::
-
+        $$
             \sum_{j} \varepsilon_j b^\dagger_j b_j + \text{constant},
+        $$
 
-        where the :math:`b^\dagger_j` are a new set fermionic creation
+        where the $b^\dagger_j$ are a new set fermionic creation
         operators that satisfy the canonical anticommutation relations.
         The new creation operators are linear combinations of the
         original ladder operators. In the most general case, creation and
         annihilation operators are mixed together:
 
-        .. math::
-
+        $$
            \begin{pmatrix}
                 b^\dagger_1 \\
                 \vdots \\
@@ -220,14 +219,14 @@ class QuadraticHamiltonian(PolynomialTensor):
                 \vdots \\
                 a_N
            \end{pmatrix},
+        $$
 
-        where :math:`W` is an :math:`N \times (2N)` matrix.
+        where $W$ is an $N \times (2N)$ matrix.
         However, if the Hamiltonian conserves particle number then
         creation operators don't need to be mixed with annihilation operators
-        and :math:`W` only needs to be an :math:`N \times N` matrix:
-
-        .. math::
+        and $W$ only needs to be an $N \times N$ matrix:
 
+        $$
            \begin{pmatrix}
                 b^\dagger_1 \\
                 \vdots \\
@@ -239,8 +238,9 @@ class QuadraticHamiltonian(PolynomialTensor):
                 \vdots \\
                 a^\dagger_N \\
            \end{pmatrix},
+        $$
 
-        This method returns the matrix :math:`W`.
+        This method returns the matrix $W$.
 
         Args:
             spin_sector (optional str): An optional integer specifying
@@ -253,13 +253,13 @@ class QuadraticHamiltonian(PolynomialTensor):
 
         Returns:
             orbital_energies(ndarray)
-                A one-dimensional array containing the :math:`\varepsilon_j`
+                A one-dimensional array containing the $\varepsilon_j$
             diagonalizing_unitary (ndarray):
-                A matrix representing the transformation :math:`W` of the
+                A matrix representing the transformation $W$ of the
                 fermionic ladder operators. If the Hamiltonian conserves
-                particle number then this is :math:`N \times N`; otherwise
-                it is :math:`N \times 2N`. If spin sector is specified,
-                then `N` here represents the number of spatial orbitals
+                particle number then this is $N \times N$; otherwise
+                it is $N \times 2N$. If spin sector is specified,
+                then $N$ here represents the number of spatial orbitals
                 rather than spin orbitals.
             constant(float)
                 The constant
@@ -354,9 +354,9 @@ class QuadraticHamiltonian(PolynomialTensor):
         This circuit performs the transformation to a basis in which the
         Hamiltonian takes the diagonal form
 
-        .. math::
-
+        $$
             \sum_{j} \varepsilon_j b^\dagger_j b_j + \text{constant}.
+        $$
 
         Returns
         -------
@@ -366,10 +366,10 @@ class QuadraticHamiltonian(PolynomialTensor):
                 can be performed in parallel. Each elementary operation
                 is either the string 'pht' indicating a particle-hole
                 transformation on the last fermionic mode, or a tuple of
-                the form :math:`(i, j, \theta, \varphi)`,
+                the form $(i, j, \theta, \varphi)$,
                 indicating a Givens rotation
-                of modes :math:`i` and :math:`j` by angles :math:`\theta`
-                and :math:`\varphi`.
+                of modes $i$ and $j$ by angles $\theta$
+                and $\varphi$.
         """
         # Adding inline import here to prevent circular issues
         # TODO: move this out once we have a better solution
@@ -418,11 +418,11 @@ class QuadraticHamiltonian(PolynomialTensor):
         Any quadratic Hamiltonian is unitarily equivalent to a Hamiltonian
         of the form
 
-        .. math::
-
+        $$
             \sum_{j} \varepsilon_j b^\dagger_j b_j + \text{constant}.
+        $$
 
-        We call the :math:`\varepsilon_j` the orbital energies.
+        We call the $\varepsilon_j$ the orbital energies.
         The eigenvalues of the Hamiltonian are sums of subsets of the
         orbital energies (up to the additive constant).
 
@@ -435,7 +435,7 @@ class QuadraticHamiltonian(PolynomialTensor):
         Returns
         -------
         orbital_energies(ndarray)
-            A one-dimensional array containing the :math:`\varepsilon_j`
+            A one-dimensional array containing the $\varepsilon_j$
         constant(float)
             The constant
         """
